import nsrunit; unit conversion on;
math EnzymeMulti { realDomain t hour; t.min=0; t.max=16.0; t.delta=0.05;


/* Enzyme model for all sets of data
   using shared parameters
 
            kf1->                  kf2->
  SA+Enzyme<-----> SAEnzymeComplex<-----> Enzyme+Product
            <-kb1                  <-kb2
   
*/
real kf1= 1 L*mg^(-1)*hour^(-1), kb1  = 10 hour^(-1), 
     kb2= 0.002 L/(mg*hour),         kf2  = 1 hour^(-1),
     Etot = 8 mg/L;
//--------------------------------------			
real LSA(t)  mg/L, LSAE(t)  mg/L,  LE(t)  mg/L, LP(t) mg/L, LSAtot = 7 mg/L;

when(t=t.min) {LSA=LSAtot; LSAE=0;}
LSA:t = -kf1*LSA*LE+kb1*LSAE;
LSAE:t = kf1*LSA*LE-kb1*LSAE-kf2*LSAE+kb2*LE*LP;
LSAtot=LSA+LSAE+LP;
Etot=LE+LSAE;
//--------------------------------------
real MSA(t)  mg/L, MSAE(t)  mg/L,  ME(t)  mg/L, MP(t) mg/L, MSAtot = 72 mg/L;

when(t=t.min) {MSA=MSAtot; MSAE=0;}
MSA:t = -kf1*MSA*ME+kb1*MSAE;
MSAE:t = kf1*MSA*ME-kb1*MSAE-kf2*MSAE+kb2*ME*MP;
MSAtot=MSA+MSAE+MP;
Etot=ME+MSAE;
//--------------------------------------
real HSA(t)  mg/L, HSAE(t)  mg/L,  HE(t)  mg/L, HP(t) mg/L, HSAtot = 341 mg/L;

when(t=t.min) {HSA=HSAtot; HSAE=0;}
HSA:t = -kf1*HSA*HE+kb1*HSAE;
HSAE:t = kf1*HSA*HE-kb1*HSAE-kf2*HSAE+kb2*HE*HP;
HSAtot=HSA+HSAE+HP;
Etot=HE+HSAE;
}